@@ -77,6 +77,7 @@ def train_from_folder(
     optimizer = 'adam',
     fmap_max = 512,
     transparent = False,
+    greyscale = False,
     batch_size = 10,
     gradient_accumulate_every = 4,
     num_train_steps = 150000,
@@ -116,6 +117,7 @@ def train_from_folder(
         optimizer = optimizer,
         fmap_max = fmap_max,
         transparent = transparent,
+        greyscale = greyscale,
         lr = learning_rate,
         save_every = save_every,
         evaluate_every = evaluate_every,
